<?php

/**
 * Haami functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Haami
 */

if (!defined('_S_VERSION')) {
	// Replace the version number of the theme on each release.
	define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function haami_setup()
{
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Haami, use a find and replace
		* to change 'haami' to the name of your theme in all the template files.
		*/
	load_theme_textdomain('haami');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support('title-tag');

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__('Primary', 'haami'),
			'top-menu' => esc_html__('Top Menu', 'haami'),
			'social-menu' => esc_html__('Social Menu', 'haami'),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'haami_custom_background_args',
			array(
				'default-color' => '#FBF8F1',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);

	// Add support for Yoast SEO Breadcrumbs.
	add_theme_support('yoast-seo-breadcrumbs');

	// Add support for Rank Math Breadcrumbs.
	add_theme_support('rank-math-breadcrumbs');
}
add_action('after_setup_theme', 'haami_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function haami_content_width()
{
	$GLOBALS['content_width'] = apply_filters('haami_content_width', 640);
}
add_action('after_setup_theme', 'haami_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function haami_widgets_init()
{
	register_sidebar(
		array(
			'name'          => esc_html__('Sidebar', 'haami'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('Add widgets here.', 'haami'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__('Footer 1', 'haami'),
			'id'            => 'footer-1',
			'description'   => esc_html__('Add widgets here.', 'haami'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__('Footer 2', 'haami'),
			'id'            => 'footer-2',
			'description'   => esc_html__('Add widgets here.', 'haami'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__('Footer 3', 'haami'),
			'id'            => 'footer-3',
			'description'   => esc_html__('Add widgets here.', 'haami'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__('Footer 4', 'haami'),
			'id'            => 'footer-4',
			'description'   => esc_html__('Add widgets here.', 'haami'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action('widgets_init', 'haami_widgets_init');


function haami_social_menu()
{
	if (has_nav_menu('social-menu')) :
		wp_nav_menu(array(
			'theme_location' => 'social-menu',
			'container' => 'ul',
			'menu_class' => 'social-menu menu',
			'menu_id'  => 'menu-social',
		));
	endif;
}

/**
 * Enqueue scripts and styles.
 */
function haami_scripts()
{

	// Load fonts locally
	require_once get_theme_file_path('inc/wptt-webfont-loader.php');

	$font_families = array(
		'Libre+Baskerville:wght@400;700',
		'Work+Sans:wght@100;200;300;400;500;600;700',
	);

	$fonts_url = add_query_arg(array(
		'family' => implode('&family=', $font_families),
		'display' => 'swap',
	), 'https://fonts.googleapis.com/css2');

	wp_enqueue_style('haami-google-fonts', wptt_get_webfont_url(esc_url_raw($fonts_url)), array(), '1.0.0');


	// Font Awesome CSS
	wp_enqueue_style('font-awesome-5', get_template_directory_uri() . '/candidthemes/assets/vendors/font-awesome-5/css/all.min.css', array());

	// Slick Slider CSS
	wp_enqueue_style('slick-slider-css', get_template_directory_uri() . '/candidthemes/assets/vendors/slick/slick.css', array());
	// Slick Slider JS
	wp_enqueue_script('slick-slider-js', get_template_directory_uri() . '/candidthemes/assets/vendors/slick/slick.js', array(), _S_VERSION, true);

	// Masonry JS
	wp_enqueue_script('masonry');

	wp_enqueue_style('haami-style', get_stylesheet_uri(), array(), _S_VERSION);
	wp_style_add_data('haami-style', 'rtl', 'replace');


	wp_enqueue_script('haami-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

	wp_enqueue_script('haami-custom-js', get_template_directory_uri() . '/candidthemes/assets/js/custom.js', array('jquery'), _S_VERSION, true);

	wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() . '/candidthemes/assets/js/theia-sticky-sidebar.js', array('jquery'), _S_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}

	wp_enqueue_script('haami-custom-pagination', get_template_directory_uri() . '/candidthemes/assets/js/infinite-pagination.js', array('jquery'), _S_VERSION, true);
	global $wp_query;
	$paged = (get_query_var('paged') > 1) ? get_query_var('paged') : 1;
	$max_num_pages = $wp_query->max_num_pages;

	wp_localize_script('haami-custom-pagination', 'haami_ajax', array(
		'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
		'paged' => absint($paged),
		'max_num_pages' => absint($max_num_pages),
		'next_posts' => next_posts(absint($max_num_pages), false),
		'show_more' => __('Load More', 'haami'),
		'no_more_posts' => __('No More', 'haami'),
		'pagination_option' => ''
	));
}
add_action('wp_enqueue_scripts', 'haami_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

// FEATURED CATEGORY SLIDER CONTROL
require get_template_directory() . '/functions/customizer-category-control.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Checkbox sanitization callback example.
 *
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function haami_sanitize_checkbox($checked)
{
	// Boolean check.
	return ((isset($checked) && true == $checked) ? true : false);
}

function haami_sanitize_select($input, $setting)
{

	// Ensure input is a slug.
	$input = sanitize_key($input);

	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control($setting->id)->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return (array_key_exists($input, $choices) ? $input : $setting->default);
}


if (!function_exists('haami_related_post')) :
	/**
	 * Display related posts from same category
	 *
	 * @param int $post_id
	 * @return void
	 *
	 * @since 1.0.0
	 *
	 */
	function haami_related_post($post_id)
	{


		$categories = get_the_category($post_id);
		if ($categories) {
			$category_ids = array();
			$category = get_category($category_ids);
			$categories = get_the_category($post_id);
			foreach ($categories as $category) {
				$category_ids[] = $category->term_id;
			}
			$count = $category->category_count;
			if ($count > 1) { ?>
				<div class="related-post">

					<h2 class="post-title">Related Posts</h2>
					<?php
					$haami_cat_post_args = array(
						'category__in' => $category_ids,
						'post__not_in' => array($post_id),
						'post_type' => 'post',
						'posts_per_page' => 3,
						'post_status' => 'publish',
						'ignore_sticky_posts' => true
					);
					$haami_featured_query = new WP_Query($haami_cat_post_args);
					?>
					<div class="rel-post-wrap">
						<?php
						if ($haami_featured_query->have_posts()) :

							while ($haami_featured_query->have_posts()) : $haami_featured_query->the_post();
						?>

								<div class="card-item rel-card-item">
									<?php
									if (has_post_thumbnail()) {
									?>

										<div class="card-media">
											<a href="<?php the_permalink(); ?>">
												<?php the_post_thumbnail(); ?>

											</a>
										</div>
									<?php
									}
									?>
									<div class="card-content">
										<div class="entry-title">
											<h3>
												<a href="<?php the_permalink() ?>">
													<?php the_title(); ?>
												</a>
											</h3>
										</div>
										<div class="entry-meta">
											<?php haami_posted_on(); ?>
										</div>
									</div>
								</div>




							<?php
							endwhile;
							?>
						<?php
						endif;
						wp_reset_postdata();
						?>
					</div> <!-- .related-post -->
				<?php
			}
		}
	}
endif;
add_action('haami_related_posts', 'haami_related_post', 10, 1);



if (!function_exists('haami_breadcrumb_construct')) {
	/**
	 * Enable/disable breadcrumb
	 *
	 * @since 1.0.0
	 *
	 */
	function haami_breadcrumb_construct()
	{

		if (('disable' != get_theme_mod('haami_breadcrumb_options', 'theme-default')) && !is_front_page()) {
			$breadcrumb_from = get_theme_mod('haami_breadcrumb_options', 'theme-default');

			if ((function_exists('yoast_breadcrumb')) && ($breadcrumb_from == 'yoast-seo')) {
				?>
					<div class="theme-breadcrumb-wrapper">
						<?php
						yoast_breadcrumb();
						?>
					</div>
				<?php
			} elseif ((function_exists('rank_math_the_breadcrumbs')) && ($breadcrumb_from == 'rank-math')) {
				?>
					<div class="theme-breadcrumb-wrapper">
						<?php
						rank_math_the_breadcrumbs();
						?>
					</div>
	<?php
			}
		}
	}
}

add_action('haami_breadcrumbs', 'haami_breadcrumb_construct', 10);

// INFINITE PAGINATION FUNCTION
if (!function_exists('haami_posts_navigation')) {
	/**
	 * Display pagination based on type seclected
	 *
	 * @since 1.0.0
	 *
	 */
	function haami_posts_navigation()
	{
		$page_number = get_query_var('paged');
		if ($page_number == 0) {
			$output_page = 2;
		} else {
			$output_page = $page_number + 1;
		}
		if (paginate_links()) {
			echo "<div class='ajax-pagination text-center view-more-btn fullwidth'><div class='show-more btn' data-number='$output_page'><i class='fa fa-refresh'></i>" . __('Load More', 'haami') . "</div><div id='free-temp-post'></div></div>";
		}
	}
}
add_action('haami_action_navigation', 'haami_posts_navigation', 10);
