<?php

/**
 * Haami Theme Customizer
 *
 * @package Haami
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function haami_customize_register($wp_customize)
{
	$wp_customize->get_setting('blogname')->transport         = 'postMessage';
	$wp_customize->get_setting('blogdescription')->transport  = 'postMessage';
	$wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

	if (isset($wp_customize->selective_refresh)) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'haami_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'haami_customize_partial_blogdescription',
			)
		);
	}

	/*
    * Theme Options Panel
    */
	$wp_customize->add_panel('haami_panel', array(
		'priority' => 25,
		'capability' => 'edit_theme_options',
		'title' => __('Haami Theme Options', 'haami'),
	));

	/* Homepage Featured Post Slider Options*/
	$wp_customize->add_section('haami_slider_section', array(
		'priority'       => 5,
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => __('Featured Post Slider', 'haami'),
		'panel'       	 => 'haami_panel',
	));

	$wp_customize->add_setting(
		'haami_feat_slider_setting',
		array(
			'capability'        => 'edit_theme_options',
			'transport' => 'refresh',
			'default'           => 0,
			'sanitize_callback' => 'absint'
		)
	);

	$wp_customize->add_control(
		new Haami_Customize_Category_Dropdown_Control(
			$wp_customize,
			'haami_feat_slider_setting',
			array(
				'label'     => __('Featured Slider Section', 'haami'),
				'description' => __('From the dropdown select the category for the featured slider section. Category having post will display in below dropdown.', 'haami'),
				'section'   => 'haami_slider_section',
				'settings'  => 'haami_feat_slider_setting',
				'type'      => 'category_dropdown',
				'priority'  => 10,
			)
		)
	);

	/* Homepage Featured Post Grid Options*/
	$wp_customize->add_section('haami_slider_section', array(
		'priority'       => 5,
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => __('Featured Post Grid', 'haami'),
		'panel'       => 'haami_panel',
	));

	$wp_customize->add_setting(
		'haami_feat_grid_setting',
		array(
			'capability'        => 'edit_theme_options',
			'transport' 		=> 'refresh',
			'default'           => 0,
			'sanitize_callback' => 'absint'
		)
	);

	$wp_customize->add_control(
		new Haami_Customize_Category_Dropdown_Control(
			$wp_customize,
			'haami_feat_grid_setting',
			array(
				'label'     	=> __('Featured Grid Section', 'haami'),
				'description' 	=> __('From the dropdown select the category for the featured grid section. Category having post will display in below dropdown.', 'haami'),
				'section'   	=> 'haami_slider_section',
				'settings'  	=> 'haami_feat_grid_setting',
				'type'      	=> 'category_dropdown',
				'priority'  	=> 10,
			)
		)
	);

	// Instagram Feed Section
	$wp_customize->add_section('haami_insta_section', array(
		'priority'       => 5,
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => __('Instragram Feed', 'haami'),
		'panel'       => 'haami_panel',
	));

	$wp_customize->add_setting(
		'haami_insta_feed_option',
		array(
			'capability'        => 'edit_theme_options',
			'transport'         => 'refresh',
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'haami_insta_feed_option',
		array(
			'label'       => __('Instragram Shortcode Field', 'haami'),
			'description' => __('Insert Instagram Shortcode below.', 'haami'),
			'section'     => 'haami_insta_section',
			'type'        => 'text',
		)
	);

	/* Customizer Footer Section*/
	$wp_customize->add_section('haami_footer_section', array(
		'priority'       => 5,
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => __('Footer Options', 'haami'),
		'panel'       => 'haami_panel',
	));


	/*Footer Social Menu Option*/
	$wp_customize->add_setting(
		'haami_footer_social_menu',
		array(
			'capability'        => 'edit_theme_options',
			'transport'         => 'refresh',
			'default'           => 1,
			'sanitize_callback' => 'haami_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'haami_footer_social_menu',
		array(
			'label'       => __('Enable Footer Social Menu', 'haami'),
			'description' => __('Checked to show the Footer Social Menu.', 'haami'),
			'section'     => 'haami_footer_section',
			'type'        => 'checkbox',
		)
	);

	/*Footer Copyright Text Enable*/
	$wp_customize->add_setting(
		'haami_copyright_option',
		array(
			'capability'        => 'edit_theme_options',
			'transport'         => 'refresh',
			'default'           => 'Copyright All Rights Reserved 2023',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'haami_copyright_option',
		array(
			'label'       => __('Edit Copyright Text', 'haami'),
			'description' => __('Edit the Footer Copyright Section.', 'haami'),
			'section'     => 'haami_footer_section',
			'type'        => 'text',
		)
	);

	/*Go To Top Option*/
	$wp_customize->add_setting(
		'haami_enable_go_to_top_option',
		array(
			'capability'        => 'edit_theme_options',
			'transport'         => 'refresh',
			'default'           => 1,
			'sanitize_callback' => 'haami_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'haami_enable_go_to_top_option',
		array(
			'label'       => __('Enable Go To Top', 'haami'),
			'description' => __('Checked to enable Go To Top option.', 'haami'),
			'section'     => 'haami_footer_section',
			'type'        => 'checkbox',
		)
	);



	/*Extra Options*/
	$wp_customize->add_section('haami_extra_section', array(
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => __('Extra Options', 'haami'),
		'panel'        => 'haami_panel',
	));

	/*Breadcrumb settings*/
	$wp_customize->add_setting(
		'haami_breadcrumb_options',
		array(
			'capability'        => 'edit_theme_options',
			'transport' => 'refresh',
			'default'           => 'disable',
			'sanitize_callback' => 'haami_sanitize_select'
		)
	);
	$wp_customize->add_control('haami_breadcrumb_options', array(
		'choices' => array(
			'disable'   => __('Disable Breadcrumb', 'haami'),
			'rank-math'   => __('Rank Math Breadcrumb', 'haami'),
			'yoast-seo'   => __('Yoast SEO Breadcrumb', 'haami'),
		),
		'label'     => __('Breadcrumb Option in Single and Blog Page', 'haami'),
		'description' => __('You can use any of the breadcrumb from the option. You need to install and activate Yoast or Rank Math plugin. ', 'haami'),
		'section'   => 'haami_extra_section',
		'settings'  => 'haami_breadcrumb_options',
		'type'      => 'select',
	));
}
add_action('customize_register', 'haami_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function haami_customize_partial_blogname()
{
	bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function haami_customize_partial_blogdescription()
{
	bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function haami_customize_preview_js()
{
	wp_enqueue_script('haami-customizer', get_template_directory_uri() . '/js/customizer.js', array('customize-preview'), _S_VERSION, true);
}
add_action('customize_preview_init', 'haami_customize_preview_js');
